@@ -455,7 +455,7 @@ if (blackOnWhite)
 -(void) drawRect: (NSRect)r
 {
 	int ix,iy;
-	unsigned char buf[8];
+	char buf[8];
 	NSGraphicsContext *cur=GSCurrentContext();
 	int x0,y0,x1,y1;
 	NSFont *f,*current_font=nil;
@@ -710,8 +710,8 @@ if (blackOnWhite)
 						}
 						else
 						{
-							unsigned char *pbuf=buf;
-							int dlen=sizeof(buf)-1;
+						        unsigned char *pbuf=(unsigned char *)buf;
+							unsigned int dlen=sizeof(buf)-1;
 							GSFromUnicode(&pbuf,&dlen,&uch,1,encoding,NULL,GSUniTerminate);
 						}
 					}
@@ -1642,6 +1642,9 @@ Selection, copy/paste/services
 	int g;
 	struct selection_range r0,r1;
 
+	
+	r0.location=r0.length=0;
+	r1=r0;
 	first=YES;
 	ofs0=0; /* get compiler to shut up */
 	g=[e clickCount];
@@ -1975,7 +1978,8 @@ Handle master_fd
 		}
 
 		if (cdirectory)
-			chdir(cdirectory);
+			if (chdir(cdirectory) < 0)
+				fprintf(stderr, "Unable do set directory: %s\n", cdirectory);
 		putenv("TERM=linux");
 		putenv("TERM_PROGRAM=GNUstep_Terminal");
 		execv(cpath,(char *const*)cargs);
