@@ -1,29 +1,34 @@
 /*
 copyright 2002, 2003 Alexander Malmberg <alexander@malmberg.org>
 
+2009-2010 GAP Project
+
 This file is a part of Terminal.app. Terminal.app is free software; you
 can redistribute it and/or modify it under the terms of the GNU General
 Public License as published by the Free Software Foundation; version 2
 of the License. See COPYING or main.m for more information.
 */
 
-#include <Foundation/NSNotification.h>
-#include <Foundation/NSString.h>
-#include <Foundation/NSUserDefaults.h>
-#include <AppKit/NSBox.h>
-#include <AppKit/NSColor.h>
-#include <AppKit/NSColorPanel.h>
-#include <AppKit/NSColorWell.h>
-#include <AppKit/NSFont.h>
-#include <AppKit/NSGraphics.h>
-#include <AppKit/NSImage.h>
-#include <AppKit/NSTextField.h>
-#include <AppKit/NSFontManager.h>
-#include <GNUstepGUI/GSVbox.h>
-#include <GNUstepGUI/GSHbox.h>
-#include "Label.h"
+#import <Foundation/NSNotification.h>
+#import <Foundation/NSString.h>
+#import <Foundation/NSUserDefaults.h>
+#import <AppKit/NSBox.h>
+#import <AppKit/NSColor.h>
+#import <AppKit/NSColorPanel.h>
+#import <AppKit/NSColorWell.h>
+#import <AppKit/NSFont.h>
+#import <AppKit/NSGraphics.h>
+#import <AppKit/NSImage.h>
+#import <AppKit/NSTextField.h>
+#import <AppKit/NSFontManager.h>
+#import <AppKit/NSButton.h>
+#import <AppKit/NSButtonCell.h>
+#import <AppKit/NSMatrix.h>
+#import <GNUstepGUI/GSVbox.h>
+#import <GNUstepGUI/GSHbox.h>
+#import "Label.h"
 
-#include "TerminalViewPrefs.h"
+#import "TerminalViewPrefs.h"
 
 
 NSString *TerminalViewDisplayPrefsDidChangeNotification=
@@ -289,7 +294,7 @@ static int scrollBackLines;
 
 		{
 			NSTextField *f;
-			NSButton *b;
+			NSButton *butt;
 			GSHbox *hb;
 
 			hb=[[GSHbox alloc] init];
@@ -313,13 +318,13 @@ static int scrollBackLines;
 			[top addView: [[[NSView alloc] init] autorelease] enablingYResizing: YES];
 
 			{
-				NSBox *b;
+				NSBox    *box;
 				GSTable *t;
 				NSColorWell *w;
 
-				b=[[NSBox alloc] init];
-				[b setAutoresizingMask: NSViewMinXMargin|NSViewMaxXMargin];
-				[b setTitle: _(@"Cursor")];
+				box=[[NSBox alloc] init];
+				[box setAutoresizingMask: NSViewMinXMargin|NSViewMaxXMargin];
+				[box setTitle: _(@"Cursor")];
 
 				t=[[GSTable alloc] initWithNumberOfRows: 2 numberOfColumns: 2];
 				[t setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];
@@ -331,16 +336,16 @@ static int scrollBackLines;
 
 				{
 					NSMatrix *m;
-					NSButtonCell *b=[NSButtonCell new];
+					NSButtonCell *bc=[NSButtonCell new];
 					NSSize s;
 
-					[b setImagePosition: NSImageOnly];
-					[b setHighlightsBy: NSChangeBackgroundCellMask];
-					[b setShowsStateBy: NSChangeBackgroundCellMask];
+					[bc setImagePosition: NSImageOnly];
+					[bc setHighlightsBy: NSChangeBackgroundCellMask];
+					[bc setShowsStateBy: NSChangeBackgroundCellMask];
 
 					m=m_cursorStyle=[[NSMatrix alloc] initWithFrame: NSMakeRect(0,0,1,1)
 						mode: NSRadioModeMatrix
-						prototype: b
+						prototype: bc
 						numberOfRows: 1
 						numberOfColumns: 4];
 
@@ -377,28 +382,28 @@ static int scrollBackLines;
 
 
 				[t sizeToFit];
-				[b setContentView: t];
-				[b sizeToFit];
-				[top addView: b enablingYResizing: NO];
-				DESTROY(b);
+				[box setContentView: t];
+				[box sizeToFit];
+				[top addView: box enablingYResizing: NO];
+				DESTROY(box);
 			}
 
 			[top addView: [[[NSView alloc] init] autorelease] enablingYResizing: YES];
 
 
-			b=b_useMultiCellGlyphs=[[NSButton alloc] init];
-			[b setTitle: _(@"Handle wide (multi-cell) glyphs")];
-			[b setButtonType: NSSwitchButton];
-			[b sizeToFit];
-			[top addView: b enablingYResizing: NO];
-			DESTROY(b);
+			butt=b_useMultiCellGlyphs=[[NSButton alloc] init];
+			[butt setTitle: _(@"Handle wide (multi-cell) glyphs")];
+			[butt setButtonType: NSSwitchButton];
+			[butt sizeToFit];
+			[top addView: butt enablingYResizing: NO];
+			DESTROY(butt);
 
-			b=b_blackOnWhite=[[NSButton alloc] init];
-			[b setTitle: _(@"Display black on white text")];
-			[b setButtonType: NSSwitchButton];
-			[b sizeToFit];
-			[top addView: b enablingYResizing: NO];
-			DESTROY(b);
+			butt=b_blackOnWhite=[[NSButton alloc] init];
+			[butt setTitle: _(@"Display black on white text")];
+			[butt setButtonType: NSSwitchButton];
+			[butt sizeToFit];
+			[top addView: butt enablingYResizing: NO];
+			DESTROY(butt);
 
 
 			hb=[[GSHbox alloc] init];
@@ -416,13 +421,13 @@ static int scrollBackLines;
 			[hb addView: f  enablingXResizing: YES];
 			DESTROY(f);
 
-			b=[[NSButton alloc] init];
-			[b setTitle: _(@"Pick font...")];
-			[b setTarget: self];
-			[b setAction: @selector(_pickBoldTerminalFont:)];
-			[b sizeToFit];
-			[hb addView: b  enablingXResizing: NO];
-			DESTROY(b);
+			butt=[[NSButton alloc] init];
+			[butt setTitle: _(@"Pick font...")];
+			[butt setTarget: self];
+			[butt setAction: @selector(_pickBoldTerminalFont:)];
+			[butt sizeToFit];
+			[hb addView: butt  enablingXResizing: NO];
+			DESTROY(butt);
 
 			[top addView: hb enablingYResizing: NO];
 			DESTROY(hb);
@@ -443,13 +448,13 @@ static int scrollBackLines;
 			[hb addView: f  enablingXResizing: YES];
 			DESTROY(f);
 
-			b=[[NSButton alloc] init];
-			[b setTitle: _(@"Pick font...")];
-			[b setTarget: self];
-			[b setAction: @selector(_pickTerminalFont:)];
-			[b sizeToFit];
-			[hb addView: b  enablingXResizing: NO];
-			DESTROY(b);
+			butt=[[NSButton alloc] init];
+			[butt setTitle: _(@"Pick font...")];
+			[butt setTarget: self];
+			[butt setAction: @selector(_pickTerminalFont:)];
+			[butt sizeToFit];
+			[hb addView: butt  enablingXResizing: NO];
+			DESTROY(butt);
 
 			[top addView: hb enablingYResizing: NO];
 			DESTROY(hb);
